@@ -71,7 +71,12 @@ class Device(Auth):
     @property
     def firmwareDesired(self) -> str:
         """Return the desired firmware version."""
-        return self.raw_data["firmware"]["desiredFwVersion"]                
+        return self.raw_data["firmware"]["desiredFwVersion"]       
+
+    @property
+    def connectionState(self) -> str:
+        """Return the connection state."""
+        return self.raw_data["connectionState"]
 
     async def async_update(self):
         """Update the device data."""
